summaryrefslogtreecommitdiff
path: root/src/lib/merchant_api_common.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-04-10 20:14:57 +0200
committerChristian Grothoff <christian@grothoff.org>2020-04-10 20:14:57 +0200
commit0b945df357bf820540b67b412d47aa9073797267 (patch)
tree4027a8711e7398070f556ae42447c101d91a063e /src/lib/merchant_api_common.c
parent831272d4344151a62d2a8ffc4188d4302f64be5b (diff)
downloadmerchant-0b945df357bf820540b67b412d47aa9073797267.tar.gz
merchant-0b945df357bf820540b67b412d47aa9073797267.tar.bz2
merchant-0b945df357bf820540b67b412d47aa9073797267.zip
implement #5299
Diffstat (limited to 'src/lib/merchant_api_common.c')
-rw-r--r--src/lib/merchant_api_common.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/lib/merchant_api_common.c b/src/lib/merchant_api_common.c
index 33175958..cb8de653 100644
--- a/src/lib/merchant_api_common.c
+++ b/src/lib/merchant_api_common.c
@@ -57,13 +57,13 @@ TALER_MERCHANT_parse_error_details_ (const json_t *response,
hr->ec = TALER_JSON_get_error_code (response);
hr->hint = TALER_JSON_get_error_hint (response);
- /* handle 'exchange-http-status' */
+ /* handle 'exchange_http_status' */
jc = json_object_get (response,
- "exchange-http-status");
+ "exchange_http_status");
/* The caller already knows that the JSON represents an error,
so we are dealing with a missing error code here. */
if (NULL == jc)
- return; /* no need to bother with exchange-code/hint if we had no status */
+ return; /* no need to bother with exchange_code/hint if we had no status */
if (! json_is_integer (jc))
{
GNUNET_break_op (0);
@@ -71,9 +71,9 @@ TALER_MERCHANT_parse_error_details_ (const json_t *response,
}
hr->exchange_http_status = (unsigned int) json_integer_value (jc);
- /* handle 'exchange-reply' */
+ /* handle 'exchange_reply' */
jc = json_object_get (response,
- "exchange-reply");
+ "exchange_reply");
if (! json_is_object (jc))
{
GNUNET_break_op (0);
@@ -83,9 +83,9 @@ TALER_MERCHANT_parse_error_details_ (const json_t *response,
hr->exchange_reply = jc;
}
- /* handle 'exchange-code' */
+ /* handle 'exchange_code' */
jc = json_object_get (response,
- "exchange-code");
+ "exchange_code");
/* The caller already knows that the JSON represents an error,
so we are dealing with a missing error code here. */
if (NULL == jc)